PermissionFlowController

Struct PermissionFlowController 

pub struct PermissionFlowController { /* private fields */ }
Main controller for driving the Swift permission flow from Rust.

Implementations

Source

impl PermissionFlowController

pub fn new() -> Result<Self, NewControllerError>

Creates a controller for starting permission flows.

This must be called on the macOS main thread.

pub fn start_flow( &self, options: StartFlowOptions, ) -> Result<(), StartPermissionFlowError>

Starts a permission flow.

The underlying library only keeps one panel open at a time, so starting a new flow closes the previous one.

pub fn stop_current_flow(&self) -> Result<(), StopPermissionFlowError>

Stops the current permission flow, if one is active.