pub struct StartFlowOptions { /* private fields */ }Expand description
Options for starting a permission flow.
Implementations
Sourceimpl StartFlowOptions
impl StartFlowOptions
Sourcepub fn new<P: Into<AppPath>>(permission: Permission, app_path: P) -> Self
pub fn new<P: Into<AppPath>>(permission: Permission, app_path: P) -> Self
Creates a new set of start-flow options.
Sourcepub fn use_click_source_frame(self, use_click_source_frame: bool) -> Self
pub fn use_click_source_frame(self, use_click_source_frame: bool) -> Self
Sets whether the current mouse location should be used as the source frame for the launch animation.
Sourcepub fn without_click_source_frame(self) -> Self
pub fn without_click_source_frame(self) -> Self
Disables the click-source-frame launch animation.
pub fn permission(&self) -> Permission
pub fn app_path(&self) -> &AppPath
pub fn uses_click_source_frame(&self) -> bool