pub struct PermissionFlowController { /* private fields */ }Expand description
Main controller for driving the Swift permission flow from Rust.
Implementations
Sourceimpl PermissionFlowController
impl PermissionFlowController
Sourcepub fn new() -> Result<Self, NewControllerError>
pub fn new() -> Result<Self, NewControllerError>
Creates a controller for starting permission flows.
This must be called on the macOS main thread.
Sourcepub fn start_flow(
&self,
options: StartFlowOptions,
) -> Result<(), StartPermissionFlowError>
pub fn start_flow( &self, options: StartFlowOptions, ) -> Result<(), StartPermissionFlowError>
Starts a permission flow.
The underlying library only keeps one panel open at a time, so starting a new flow closes the previous one.
Sourcepub fn stop_current_flow(&self) -> Result<(), StopPermissionFlowError>
pub fn stop_current_flow(&self) -> Result<(), StopPermissionFlowError>
Stops the current permission flow, if one is active.